# Code of Conduct

This project has adopted the ACM Code of Ethics and Professional Conduct ([https://www.acm.org/code-of-ethics](https://www.acm.org/code-of-ethics)) in the version adopted in June 22nd, 2018.
